# Multi-Precision Listing

```{doxygenclass} librapid::mpz
    :members:
    :protected-members:
    :undoc-members:
```

---

```{doxygenclass} librapid::mpq
    :members:
    :protected-members:
    :undoc-members:
```

---

```{doxygenclass} librapid::mpf
    :members:
    :protected-members:
    :undoc-members:
```

---

```{doxygenclass} librapid::mpfr
    :members:
    :protected-members:
    :undoc-members:
```
